package com.example.printer_module_bixolon;

import android.bluetooth.BluetoothDevice;
import android.content.Context;
import android.content.Intent;
import android.os.Handler;
import android.os.Message;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import com.bixolon.printer.BixolonPrinter;

import java.util.Map;
import java.util.Set;

/** PrinterModuleBixolonPlugin */
public class PrinterModuleBixolonPlugin implements MethodCallHandler, PluginRegistry.ActivityResultListener {
  /** Plugin registration. */
  public Result result;
  private static String deviceName;
  private static String deviceAddress;
  private static String deviceIpAddress;
  private static boolean status = false;
  //private static String status = "Disconnected";
  private static BixolonPrinter bixolonPrinter;

  static final Integer REQUEST_CODE_SELECT_FIRMWARE = Integer.MAX_VALUE;
  static final Integer RESULT_CODE_SELECT_FIRMWARE = Integer.MAX_VALUE - 1;
  static final Integer MESSAGE_START_WORK = Integer.MAX_VALUE - 2;
  static final Integer MESSAGE_END_WORK = Integer.MAX_VALUE - 3;

  static final String FIRMWARE_FILE_NAME = "FirmwareFileName";
  private Map<String, Object> arguments;

  public static Context context;

  public static void registerWith(Registrar registrar) {
    context = registrar.context();
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "printer_module_bixolon");
    channel.setMethodCallHandler(new PrinterModuleBixolonPlugin());
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("create")) {
      create();
    } else if (call.method.equals("connectWifiPrinter")) {
      if (!(call.arguments instanceof Map)) {
        throw new IllegalArgumentException("Plugin not passing a Map as parameter");
      }
      arguments = (Map<String, Object>) call.arguments;
      findWifiPrinter((String) arguments.get("ipAddress"));
    } else if (call.method.equals("connectBluetoothPrinter")){
      if (!(call.arguments instanceof Map)){
        throw new IllegalArgumentException("Plugin not passing a map as parameter");
      }
      arguments = (Map<String, Object>) call.arguments;
      findBluetoothPrinter((String) arguments.get("deviceName"));
    }
    else if (call.method.equals("checkStatus")) {
      checkStatus(result);
    } else if (call.method.equals("print")) {
      if (!(call.arguments instanceof Map)) {
        throw new IllegalArgumentException("Plugin not passing a Map as parameter");
      }
      arguments = (Map<String, Object>) call.arguments;
      printText((String) arguments.get("text"));
    } else if(call.method.equals("disconnect")){
      disconnect();
    } else {
      result.notImplemented();
    }
  }

  private final Handler handler = new Handler(new Handler.Callback() {
    @Override
    public boolean handleMessage(Message message) {
      Log.d("bixolon", "mHandler.handleMessage(" + message + ")");
      switch (message.what) {
        case BixolonPrinter.MESSAGE_BLUETOOTH_DEVICE_SET:
          Set<BluetoothDevice> bluetoothDeviceSet = (Set<BluetoothDevice>) message.obj;
          for (BluetoothDevice device : bluetoothDeviceSet) {
            if (device.getName().equals(deviceName)) {
              deviceAddress = device.getAddress();
              bixolonPrinter.connect(deviceAddress);
              break;
            }
          }

          break;
        case BixolonPrinter.MESSAGE_NETWORK_DEVICE_SET:
          if (message.obj != null) {
            Set<String> ipAddressSet = (Set<String>) message.obj;
            for (String ipAddress : ipAddressSet) {
              if (ipAddress.equals(deviceIpAddress)) {
                Log.d("ipAddress", ipAddress);
                bixolonPrinter.connect(deviceIpAddress, 9100, 5000);
                break;
              }
            }
          }
          break;
        case BixolonPrinter.MESSAGE_STATE_CHANGE:
          switch (message.arg1) {
            case BixolonPrinter.STATE_CONNECTING:
              Log.d("bixolon", "Connecting");
              break;
            case BixolonPrinter.STATE_CONNECTED:
              Log.d("bixolon", "Connected");
              status = true;
              break;
            case BixolonPrinter.STATE_NONE:
              Log.d("bixolon", "None");
              status = false;
              break;
          }
          break;
        case BixolonPrinter.MESSAGE_DEVICE_NAME:

          break;
        case BixolonPrinter.MESSAGE_TOAST:

          break;
      }

      return true;
    }
  });

  @Override
  public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
    if (requestCode == REQUEST_CODE_SELECT_FIRMWARE && resultCode == RESULT_CODE_SELECT_FIRMWARE) {
      final String binaryFilePath = data.getStringExtra(FIRMWARE_FILE_NAME);
      handler.obtainMessage(MESSAGE_START_WORK).sendToTarget();
      new Thread(new Runnable() {
        public void run() {
          bixolonPrinter.updateFirmware(binaryFilePath);
          try {
            Thread.sleep(5000);
          } catch (InterruptedException e) {
            e.printStackTrace();
          }
          handler.obtainMessage(MESSAGE_END_WORK).sendToTarget();
        }
      }).start();
    } else {
      return false;
    }
    return false;
  }


  public void create() {
    bixolonPrinter = new BixolonPrinter(context, handler, null);
  }

  public void findWifiPrinter(String ipAddress) {
    deviceIpAddress = ipAddress;
    bixolonPrinter.findNetworkPrinters(5000);
  }

  public void findBluetoothPrinter(String name){
    deviceName = name;
    bixolonPrinter.findBluetoothPrinters();
  }

  public void disconnect(){
    bixolonPrinter.disconnect();
  }

  public void checkStatus(final Result result) {
    result.success(status);
  }

  public void printText(String text) {
    char alignment, attribute, fontSize, lineFeed;
    String tempText;
    Integer attributeSetting = 0, attributeAlignment = 0, attributeSize = 0;
    String[] textList = text.split("/n");
    int countLine = textList.length;

    for (int line = 0; line <countLine; line++) {
      tempText = textList[line];

      attribute = Character.toUpperCase(tempText.charAt(0));
      if (attribute == 'E') { //Bold
        attributeSetting = BixolonPrinter.TEXT_ATTRIBUTE_EMPHASIZED;
      } else if (attribute == 'B') { //Highlight
        attributeSetting = BixolonPrinter.TEXT_ATTRIBUTE_REVERSE;
      }

      alignment = Character.toUpperCase(tempText.charAt(2));
      if (alignment == 'L') {
        attributeAlignment = BixolonPrinter.ALIGNMENT_LEFT;
      } else if (alignment == 'C' || alignment == 'M') {
        attributeAlignment = BixolonPrinter.ALIGNMENT_CENTER;
      } else if (alignment == 'R') {
        attributeAlignment = BixolonPrinter.ALIGNMENT_RIGHT;
      }

      fontSize = Character.toUpperCase(tempText.charAt(4));
      if (fontSize == '1') {
        attributeSize = BixolonPrinter.TEXT_SIZE_HORIZONTAL1;
        attributeSize |= BixolonPrinter.TEXT_SIZE_VERTICAL1;
      } else if (fontSize == '2') {
        attributeSize = BixolonPrinter.TEXT_SIZE_HORIZONTAL2;
        attributeSize |= BixolonPrinter.TEXT_SIZE_VERTICAL2;
      } else if (fontSize == '3') {
        attributeSize = BixolonPrinter.TEXT_SIZE_HORIZONTAL3;
        attributeSize |= BixolonPrinter.TEXT_SIZE_VERTICAL3;
      } else if (fontSize == '4') {
        attributeSize = BixolonPrinter.TEXT_SIZE_HORIZONTAL4;
        attributeSize |= BixolonPrinter.TEXT_SIZE_VERTICAL4;
      }

      lineFeed = Character.toUpperCase(tempText.charAt(6));
      int lineSpace = 1;
      if(lineFeed == '1'){
        lineSpace = 1;
      } else if (lineFeed == '2'){
        lineSpace = 2;
      }

      String textToPrint = tempText.substring(6);

      bixolonPrinter.printText(textToPrint, attributeAlignment, attributeSetting, attributeSize, true);
      bixolonPrinter.lineFeed(lineSpace, true);
    }
    bixolonPrinter.lineFeed(3, true);
    bixolonPrinter.cutPaper(true);
  }
}
