#import "PrinterModuleBixolonPlugin.h"

@implementation PrinterModuleBixolonPlugin

NSDictionary *arguments;

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"printer_module_bixolon"
            binaryMessenger:[registrar messenger]];
  PrinterModuleBixolonPlugin* instance = [[PrinterModuleBixolonPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if ([@"getPlatformVersion" isEqualToString:call.method]) {
        [self getPlatform: result];

    //-initialize printer--------------------------------------------------------
    } else if ([@"create" isEqualToString:call.method]) {
        [self initializePrinter];

    //-connect wifi printer------------------------------------------------------
    } else if ([@"connectWifiPrinter" isEqualToString:call.method]){
        if(![call.arguments isKindOfClass:[NSDictionary class]]){
            NSLog(@"plugin not passing a map as parameter");
        }
        arguments = call.arguments;
        const char *ipAddressAsChar = [arguments[@"ipAddress"] cStringUsingEncoding:[NSString defaultCStringEncoding]];
        [self bridge_addPrinterToList:"SRP-350plusIII" LogicName:"bixolonPrinter" Type:2 Address:ipAddressAsChar Port:9100];

    //-connect bluetooth printer-------------------------------------------------
    } else if ([@"connectBluetoothPrinter" isEqualToString:call.method]){
        if(![call.arguments isKindOfClass:[NSDictionary class]]){
            NSLog(@"Plugin not passing a map as parameter");
        }
        arguments = call.arguments;
        const char *bdAddress = [arguments[@"bdAddress"] cStringUsingEncoding:[NSString defaultCStringEncoding]];
        NSLog(arguments[@"bdAddress"]);
        [self bridge_addPrinterToList:"SPP-R310" LogicName:"bixolonPrinter" Type:0 Address:bdAddress Port:0];

    //-Print text----------------------------------------------------------------
    } else if ([@"print" isEqualToString:call.method]){
        if(![call.arguments isKindOfClass:[NSDictionary class]]){
            NSLog(@"Plugin not passing a map as parameter");
        }
        arguments = call.arguments;
        const char *textToPrint = [arguments[@"data"] cStringUsingEncoding:[NSString defaultCStringEncoding]];
        [self bridge_doPrintText:textToPrint];

    //-Disconnect printer---------------------------------------------------------
    } else if([@"disconnect" isEqualToString:call.method]){
        [self bridge_disconnectPrinter];

    //-Check status---------------------------------------------------------------
    } else if([@"checkStatus" isEqualToString:call.method]){
        [self bridge_checkStatus:result];
    } else {
        result(FlutterMethodNotImplemented);
    }
}

- (void) getPlatform :(FlutterResult) result{
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
}

- (void) initializePrinter {
    [PrinterFunction initializePrinter];
}

- (void) bridge_addPrinterToList:(const char *)modelName LogicName:(const char *)logicName Type:(int)type Address:(const char *)address Port:(int)port {

    [PrinterFunction addPrinterToList:modelName LogicName:logicName Type:type Address:address Port:port];
}

- (void) bridge_disconnectPrinter {
    [PrinterFunction disconnectPrinter];
}

- (void) bridge_checkStatus :(FlutterResult) result{
    result([PrinterFunction checkStatus]);
}

- (void) bridge_doPrintText:(const char *)data{
    [PrinterFunction doPrintText:data];
}

@end
